@@ -81,14 +81,18 @@ class ValueSizeConstraintTestCase(unittest.TestCase):
             assert 0, 'constraint check fails'
 
 class PermittedAlphabetConstraintTestCase(SingleValueConstraintTestCase):
+    def setUp(self):
+        self.c1 = constraint.PermittedAlphabetConstraint('A', 'B', 'C')
+        self.c2 = constraint.PermittedAlphabetConstraint('DEF')
+
     def testGoodVal(self):
         try:
-            self.c1(1)
+            self.c1('A')
         except error.ValueConstraintError:
             assert 0, 'constraint check fails'
     def testBadVal(self):
         try:
-            self.c1(4)
+            self.c1('E')
         except error.ValueConstraintError:
             pass
         else:
