@@ -115,7 +115,15 @@ class OctetStringTestCase(unittest.TestCase):
         assert univ.OctetString('abcd').asOctets() == str2octs('abcd'), 'testAsOctets() fails'
     def testAsInts(self):
         assert univ.OctetString('abcd').asNumbers() == (97, 98, 99, 100), 'testAsNumbers() fails'
-                
+
+    def testEmpty(self):
+        try:
+            str(univ.OctetString())
+        except PyAsn1Error:
+            pass
+        else:
+            assert 0, 'empty OctetString() not reported'
+            
     def testAdd(self):
         assert univ.OctetString('') + 'q' == str2octs('q'), '__add__() fails'
     def testRadd(self):
@@ -205,7 +213,7 @@ class RealTestCase(unittest.TestCase):
 
 class ObjectIdentifier(unittest.TestCase):
     def testStr(self):
-        assert str(univ.ObjectIdentifier((1,3,6))) == '(1, 3, 6)'
+        assert str(univ.ObjectIdentifier((1,3,6))) == '1.3.6'
     def testEq(self):
         assert univ.ObjectIdentifier((1,3,6)) == (1,3,6), '__cmp__() fails'
     def testAdd(self):
